@@ -25,7 +25,7 @@ package Spreadsheet::Read;
 use strict;
 use warnings;
 
-our $VERSION = "0.56";
+our $VERSION = "0.57";
 sub  Version { $VERSION }
 
 use Carp;
@@ -333,7 +333,6 @@ sub ReadData
 	defined $opt{quote} and $quo = $opt{quote};
 	if ($io_fil) {
 	    unless (defined $opt{quote} && defined $opt{sep}) {
-		local $/ = $/;
 		open $in, "<", $txt or return;
 		$_ = <$in>;
 
@@ -473,6 +472,19 @@ sub ReadData
 	    my $sheet_idx = 1 + @data;
 	    $debug and print STDERR "\tSheet $sheet_idx '$sheet{label}' $sheet{maxrow} x $sheet{maxcol}\n";
 	    if (exists $oWkS->{MinRow}) {
+		if ($opt{clip}) {
+		    my ($mr, $mc) = (-1, -1);
+		    foreach my $r ($oWkS->{MinRow} .. $sheet{maxrow}) {
+			foreach my $c ($oWkS->{MinCol} .. $sheet{maxcol}) {
+			    my $oWkC = $oWkS->{Cells}[$r][$c] or next;
+			    defined (my $val = $oWkC->{Val})  or next;
+			    $val =~ m/\S/ or next;
+			    $r > $mr and $mr = $r;
+			    $c > $mc and $mc = $c;
+			    }
+			}
+		    ($sheet{maxrow}, $sheet{maxcol}) = ($mr + 1, $mc + 1);
+		    }
 		foreach my $r ($oWkS->{MinRow} .. $sheet{maxrow}) {
 		    foreach my $c ($oWkS->{MinCol} .. $sheet{maxcol}) {
 			my $oWkC = $oWkS->{Cells}[$r][$c] or next;
@@ -1034,7 +1046,7 @@ This modules comes with a few tools that perform tasks from the FAQ, like
 "How do I select only column D through F from sheet 2 into a CSV file?"
 
 If the module was installed without the tools, you can find them here:
-  http://repo.or.cz/w/Spreadsheet-Read.git/tree/HEAD:/examples
+  https://github.com/Tux/Spreadsheet-Read/tree/master/examples
 
 =head2 C<xlscat>
 
